     *   1         2         3         4        5          6         7
     *789012345678901234567890123456789012345678901234567890123456789012
     *LABEL    OP---OPERAND---------------------------------------------
     * 
     * THIS IS A LOADER THAT IS LOADED BY THE BOOTLOADER.
     * SOURCE INTERPRETATION BY: BOB FERETICH
     * INPUT IS FROM THE CARD PUNCH. CARD FORMAT IS...
     * COLS 1-3 DESTINATION ADDRESS WHERE THE DATA FROM THE CARD WILL 
     *            START TO LOAD.
     *      4-5 COUNT OF CHARACTER LOCATIONS THAT ARE TO BE LOADED FROM 
     *            THIS CARD.
     *      6   DATA STARTS HERE 
     *
     *      IF A WORD SEPERATOR (WS) CHARACTER APPEARS IN THE DATA AREA 
     *      FOLLOWED BY A NON-WS CHARACTER, THEN THE WS IS TO BE 
     *      DROPPED AND THE WORD MARK BIT IS TO BE TURNED ON FOR THAT 
     *      NEXT CHARACTER. 
     * 
     *      IF A WORD SEPERATOR (WS) CHARACTER APPEARS IN THE DATA AREA 
     *      FOLLOWED BY ANOTHER WS CHARACTER, THEN ONE WS IS TO BE 
     *      DROPPED AND THE OTHER IS TO BE LOADED IN MEMORY. THE WORD
     *      MARK BIT IS NOT TURNED ON. 
     *
     *      THE LAST CARD OF THE DECK BEING LOADED TYPICALLY SPECIFIES 
     *      THE LOAD OF A SINGLE UNCONDITIONAL BRANCH OR CLEAR STORAGE 
     *      AND BRANCH INSTRUCTION (CLEARING THE CARD INPUT AREA 1-80).
     *      THE LOADER DETECTS THE WORD MARK ON LOCATION 006 AND 
     *      BRANCHES TO LOCATION 006. THE CHARACTER COUNT IS ONE MORE
     *      THAN THE NUMBER OF STORAGE LOCATIONS THAT NEED LOADED FROM 
     *      THE CARD. I DO NOT KNOW WHY. 
     *      TYPICAL LAST CARDS...
     *               11111  
     *      12345678901234  <- CARD COLUMN NUMBER
     *      00608_/XXX080   <- CLEAR 000-080 AND BRANCH TO ADDRESS XXX
     *      00605_BXXX     <- UNCONDITIONAL BRANCH TO XXX
     * 
     * LAYOUT OF CARD INPUT AREA
     CARDB     EQU  1     LEFT MOST CHARACTER IN CARD INPUT AREA 
     CDDEST    EQU  1     THREE DIGIT DESTINATION FIELD
     COUNT     EQU  4     TWO DIGIT COUNT FIELD
     GOLOC     EQU  6     GO HERE TO START LOADED PROGRAM
     DATABG    EQU  6     DATA TO BE LOADED BEGINS IN COLUMN 6
     CARDE     EQU  80    RIGHT MOST CHARACTER IN CARD INPUT AREA 
     *
               ORG  201    BEGINNING OF PROGRAM
     * *****************************************************************
     * THIS LOADER INITIALIZES BY CLEARING OUT THE CARD INPUT AREA AND  
     * REESTABLISHING THE TAPE MARK AT LOCATION 001.
     * *****************************************************************
     * 
     START     CS   CARDE  CLEAR THE CARD INPUT AREA
     *                                                   201 / 080
               SW   CARDB  PUT BACK THE STARTING WORD MARK WE CLEARED
     * *****************************************************************
     * IF WE SET A WORD MARK (WM) IN COLUMN 6, START THE PROGRAM BY 
     * BRANCHING TO THE INSTRUCTION AT THIS LOCATION. THIS EXITS THE
     * LOADER PROGRAM.
     * *****************************************************************
     MAINLP    BW   GOLOC,GOLOC  IF WORD MARK APPEARS GOTO IT
     *                                                   209 V 006 006 1
               R                 READ THE NEXT CARD
     *                                                   217 1
               MLC  STRTAD&1,MV1&3  THE 1ST CHAR PAIR IS AT COLUMN 6 & 7
     *                                                   218 L 318 260
     * *****************************************************************
     * THIS IS THE BEGINNING OF A LOOP THAT PROCESSES EACH CHARACTER
     * ON THE CARD. THE LOOP STARTS BY SETTING A WM AT 004 TO MARK THE 
     * COUNT FIELD IN THE CARD AREA. IT ALSO POSITIONS THE A-REG TO THE 
     * CARDS DESTINATION ADDRESS FIELD AND THE B-REG TO THE  
     * DESTINATION FIELD OF THE MV2 INSTRUCTION. 
     * *****************************************************************
     CLOOP     SW   COUNT,MV2NSI   SET WM FOR CNT SRC & SETUP B-REG
     *                                                   225 , 004 275
     * *****************************************************************
     * THE INSTRUCTION LABELED UCW HAS BOTH ITS OPCODE AND A-ADDR 
     * MODIFIED. IT SWITCHES BETWEEN A SW AND CW INSTRUCTION. THE
     * INSTRUCTION SHOULD SET A WM IF A WORD SEPERATOR (WS) CHARACTER IS
     * THE FIRST CHARACTER IN THE CHARACTER PAIR. THE WS CHARACTER IS
     * THEN REPLACED BY THE REAL CHARACTER THAT IS SUPPOSED TO RESIDE 
     * AT THE LOCATION. IF THE THE FIRST CHARACTER OF THE PAIR IS NOT 
     * A WS THEN THE WM IS CLEARED AT THE STORAGE DESTINATION LOCATION.
     * *****************************************************************
               MLC               MOVE DEST ADDR TO UCW+3
     *                                                   232 M
     * *****************************************************************
     * THE NEXT INSTRUCTION MODIFIES THE OPCODE OF UCW TO MAKE IT A
     * CLEAR WORD MARK (CW) INSTRUCTION. IT ALSO SETS UP THE B-REG TO 
     * POINT TO THE DESTINATION ADDRESS OF MV2.
     * *****************************************************************
               MLC  CWOP  REESTABLISH CW OPCODE, ASSUME NOT WS
     *                                                   233 M 319
     * *****************************************************************
     * MOVE THE ADDRESS OF THE NEXT STORAGE LOCATION TO BE LOADED 
     * INTO THE DESTINATION ADDRESS FIELD OF MV2.
     * *****************************************************************
               MLC  CDDEST&3     MOVE DEST ADDR TO MV2 DEST
     *                                                   237 M 003
     * *****************************************************************
     * DECRIMENT THE CARDS COUNT FIELD.
     * *****************************************************************
               S    ONE,COUNT&1  DECRIMENT COUNT
     *                                                   241 S 325 005
     * *****************************************************************
     * INCREMENT THE CARDS DESTINATION ADDRESS FIELD. 
     * *****************************************************************
               MA                ADD ONE TO CARDS DEST PTR
     *                                                   248 #
     * *****************************************************************
     * IF THE CARDS COUNT FIELD<0 THEN READ A NEW CARD 
     * *****************************************************************
               BM   MAINLP,COUNT&1  LOOP IF COUNT<0
     *                                                   249 V 209 005 K
     * *****************************************************************
     * MOVES A CHARACTER PAIR TO THE CHARS BUFFER. THE INSTRUCTIONS 
     * SOURCE ADDRESS IS MODIFIED TO TRACK THE ACTIVE CARD READER
     * AREA SOURCE COLUMN. 
     * *****************************************************************
     MV1       MLC  SRCCOL,CHARS&1  MOVE NEXT PAIR OF CHARACTERS
     *                                                   257 M 007 321
     * *****************************************************************
     * MOVES LEFT CHARACTER OF THE CHARS PAIR TO THE STORAGE DESTINATION
     * LOCATION TO BE LOADED. ITS DESTINATION FIELD IS INCREMENTED 
     * TO MOVE DATA THE NEXT STORAGE LOCATION TO BE LOADED.
     * *****************************************************************
     MV2       MLC  CHARS,000    MOVE LEFT CHAR TO UPDATED ADDR
     *                                                   264 M 320 000
     MV2NSI    EQU  *
     * *****************************************************************
     * THE NEXT INSTRUCTION IS ALTERED TO EITHER SET OR CLEAR A WORD
     * MARK DEPENDING ON WHETHER THE FIRST CHARACTER OF THE CHARACTER
     * PAIR IS A WORD SEPARATOR. IF ITS A WORD SEPARATOR, THEN WE SET
     * A WORD MARK.
     * *****************************************************************
     UCW       CW   000          CLEAR WM AT DEST ADDR
     *                                                   271 < 000
     * *****************************************************************
     * INCREMENT COL PTR BY 1
     * *****************************************************************
     INCCOL    A    ONEADR,MV1&3  INCREMENT COL PTR BY 1
     *                                                   275 A 324 260
     * *****************************************************************
     * BRANCH IF THE CHAR MOVED WAS WS TO DO MORE WORK BEFORE MOVING TO 
     * NEXT CHARACTER. OUR WORK IS NOT DONE YET.
     * *****************************************************************
               BCE  SKIP1,CHARS,_  BRANCH IF THE CHAR MOVED WAS WS
     *                                                   282 B 294 320 _
     * *****************************************************************
     * IF  WE ARE HERE THEN WE MOVED A NON WS CHARACTER, SO OUR WORK
     * IS COMPLETE AND WE CAN PROCEED TO LOAD THE NEXT CHARACTER.
     * *****************************************************************
               B    CLOOP   JUST MOVED A NON-WS CHARACTER 
     *                                                   290 B 225
     * *****************************************************************
     * IF WE ARE HERE WE JUST MOVED A WORD SEPARATOR (WS) CHARACTER.
     * WE NEED TO MOVE THE NEXT CHARACTER TO THAT SPOT AND SET THE
     * WORD MARK BIT IN THAT CHARACTER. CHARS CONTAINS A WS FOLLOWED 
     * BY THE REAL CHARACTER.
     * NOTE THAT IF BOTH CHARACTERS IN A PAIR ARE WS THEN THE LOADER
     * IS TO LOAD ONE WS.
     * *****************************************************************
     * WE MAY BE GOING BACK A FEW STEPS, SO ZERO OUT THE FIRST CHAR
     * WS SO THAT IT DOESN'T SEND US BACK THIS WAY.
     * *****************************************************************
     SKIP1     S    CHARS        ZERO THE FIRST CHAR IN PAIR 
     *                                                   294 S 320
     * *****************************************************************
     * IF THE SECOND CHARACTER OF THE PAIR IS ALSO A WORD SEPARATOR(WS),
     * THEN BRANCH TO SKIP OVER THE WS IN THE CARD, SO THAT ONE OF
     * THE PAIR OF WORD SEPARATORS IS COMPRESSED OUT.
     * *****************************************************************
               BCE  INCCOL,CHARS&1,_  BRANCH IS 2ND CHAR IS WS TOO
     *                                                   298 B 275 321 _
     * *****************************************************************
     * IF WE ARE HERE THEN WE HAVE A WS FOLLOWED BY A REGULAR CHARACTER
     * AND WE NEED TO...
     * 1. MOVE SET A WORD MARK AT THE CURRENT DEST LOCATION.
     * 2. MOVE THE REGULAR CHARACTER TO THE DESTINATION STORAGE LOCATION
     *    OVERLAYING THE WS THAT WE PUT THERE A MOMENT AGO.
     * *****************************************************************
     * ALTER THE OPCODE OF THE UCW INSTRUCTION TO MAKE IT A SM.
     * *****************************************************************
               MLC  CLOOP,UCW  ALTER UCW OPCODE TO BE A SET WORD MARK
     *                                                   306 M 225 271
     * *****************************************************************
     * LOOP BACK TO MOVE THE REGULAR CHARACTER AND SET THE WORD MARK.
     * *****************************************************************
               B    MV1      MOVE THE NEXT PAIR OF CHARS
     *                                                   313 B 257
     * *****************************************************************
     * *****************************************************************
     * *****   BEGIN CONSTANTS AND DATA VARIABLE AREA          *********
     * *****************************************************************
     * *****************************************************************
     * USED TO START CARD COLUMN PROCESSING AT COLUMN 6-7 TO FETCH THE
     * FIRST CHARACTER PAIR. ITS MOVED EVERY TIME A NEW CARD IS READ.
     * *****************************************************************
     STRTAD    DCW  @07@         1ST CHAR PAIR IS IN CARD COLUMN 6 & 7
     *                                                   317 07
     * *****************************************************************
     * USED TO REINITIALIZE THE OPCODE OF THE UCW INSTRUCTION TO CW.
     * *****************************************************************
     CWOP      CW                A CLEAR WORD MARK OPCODE
     *                                                   319 <
     * *****************************************************************
     * BEWARE. ADDRESS CHAINING IS USED BETWEEN THE BELOW FIELDS.
     * DO NOT CHANGE THEIR ORDER OR INSERT NEW FIELDS.  
     * *****************************************************************
     * A TWO CHARACTER BUFFER. A PAIR OF CHARACTERS IS MOVED HERE BY THE
     * MV1 INSTRUCTION. THE PROGRAM USES THIS A AN INTERMEDIATE BUFFER.
     * THE MV2 INSTRUCTION MOVES THE 1ST CHARACTER IN THE CHARS BUFFER
     * TWO ITS LOAD DESTINATION LOCATION. A PAIR OF CHARACTERS IS USED
     * BECAUSE WORD SEPARATOR CHARACTERS NOT SUPPOSED TO BE LOADED AS 
     * DATA, BUT RATHER THEY INDICATE THAT THE NEXT SEQUENTIAL
     * CHARACTER IS TO BE LOADED WITH ITS WORD MARK BIT TURNED ON.
     * IF BOTH CHARACTER IN THE PAIR ARE WS CHARACTERS, THEN THE LOADER
     * IS SUPPOSED TO DROP ONE WS AND LOAD THE OTHER.
     * THE PAIR BUFFER GIVE THE LOADER A CONVIENENT SPOT TO EXAMINE 
     * BOTH CHARACTERS OF THE PAIR.
     * *****************************************************************
     CHARS     DCW  #2           CURRENT CHARACTER LEFT MAY BE WS
     *                                                   320 
     * *****************************************************************
     * A CONSTANT 1 USED TO INCREMENT ADDRESSES. 
     * *****************************************************************
     ONEADR    DCW  @001@        INITIAL TO 1, THEN DOUBLES
     *                                                   322 001
     * *****************************************************************
     * A CONSTANT 1. USED TO DECRIMENT COUNTERS.
     * *****************************************************************
     ONE       DCW  @1@          SINGLE DIGIT CONSTANT 1 AND READ OP
     *                                                   325 1 
     * *****************************************************************
     * THE BELOW LABEL IS JUST USED TO MAKE SOME OF THE CODE MORE 
     * READABLE. THE OPERANDS THAT REFERENCE IT ARE INITIALIZE TO 7,
     * BUT THEY ARE ALTERED BY OTHER INSTRUCTIONS.
     * *****************************************************************
     SRCCOL    EQU  7     ADDR FIELD STARTS AS 7 GETS INCREMENTED
               END  START
